0.4.0
-----
- #6: added 'security' config option: emails can now be sent via starttls, ssl, or none.
- #8: stdout/stderr is now also captured when a subprocess times out (easy with new language features)
